package Drawnings;

import java.awt.*;
import java.util.Random;
import Entities.*;
import MovementStrategy.*;

public class DrawingAirbus {

    public EntityAirbus entityAirbus;
    public IDrawingPortholes _portholes;
    private int _pictureWidth;
    private int _pictureHeight;
    protected int _startPosX;
    protected int _startPosY;
    private int _airbusWidth = 210;
    private int _airbusHeight = 100;

    public int GetPosX() { return  _startPosX; }
    public int GetPosY() { return _startPosY; }
    public int GetWidth() { return  _airbusWidth; }
    public int GetHeight() { return  _airbusHeight; }

    public DrawingAirbus(int speed, float weight, Color bodyColor, int countPortholes, int width, int height) {
        if (width < _airbusHeight || height < _airbusWidth)
            return;
        _pictureWidth = width;
        _pictureHeight = height;
        entityAirbus = new EntityAirbus(speed, weight, bodyColor);

        Random random = new Random();
        switch (random.nextInt(0,3)) {
            case 0:
                _portholes = new DrawingPortholesCircle();
                break;
            case 1:
                _portholes = new DrawingPortholesHeart();
                break;
            case 2:
                _portholes = new DrawingPortholesSquare();
                break;
            default:
                _portholes = new DrawingPortholesCircle();
                break;
        }
        _portholes.SetCount(countPortholes);
    }

    public void SetPosition (int x, int y) {
        if (x > _pictureWidth || y > _pictureHeight || x < 0 || y < 0)
        {
            _startPosX = 0;
            _startPosY = 0;
        }
        else
        {
            _startPosX = x;
            _startPosY = y;
        }
    }

    public boolean CanMove(Direction direction)
    {
        if (entityAirbus == null)
        {
            return false;
        }
        switch (direction)
        {
            case Left:
                return _startPosX - entityAirbus.Step > 5;
            case Right:
                return _startPosX + _airbusWidth + entityAirbus.Step < _pictureWidth;
            case Up:
                return _startPosY - entityAirbus.Step > 0;
            case Down:
                return _startPosY + _airbusHeight + entityAirbus.Step < _pictureHeight;
            default:
                return false;
        }
    }

    public void MoveTransport(Direction direction){
        if (!CanMove(direction) || entityAirbus == null)
        {
            return;
        }

        switch (direction) {
            case Left:
            _startPosX -= entityAirbus.Step;
            break;
        case Right:
            _startPosX += entityAirbus.Step;
            break;
        case Up:
            _startPosY -= entityAirbus.Step;
            break;
        case Down:
            _startPosY += entityAirbus.Step;
            break;
        }
    }

    public void DrawTransport(Graphics2D g) {

        if (entityAirbus == null) {
            return;
        }


        g.setColor(Color.BLACK);
//Тело
        g.setColor(entityAirbus.getBodyColor());
        g.fillRect(_startPosX + 5, _startPosY + 50, 170, 30);
        g.fillArc(_startPosX - 5, _startPosY + 50, 20, 30, 90, 180);
        g.setColor(Color.BLACK);
        g.drawRect(_startPosX + 5, _startPosY + 50, 170, 30);
        g.drawArc(_startPosX - 5, _startPosY + 50, 20, 30, 90, 180);

        _portholes.Draw(g, _startPosX+30, _startPosY+34);
//Заднее крыло
        g.setColor(Color.BLACK);
        g.drawPolygon(new int[] {_startPosX + 50,_startPosX, _startPosX}, new int[] {_startPosY + 50, _startPosY, _startPosY + 50}, 3);
        g.setColor(entityAirbus.getBodyColor());
        g.fillPolygon(new int[] {_startPosX + 50,_startPosX, _startPosX}, new int[] {_startPosY + 50, _startPosY, _startPosY + 50}, 3);
//Заднее боковые крылья
        g.setColor(Color.BLACK);
        g.drawOval(_startPosX - 7, _startPosY + 45, 30, 8);
        g.setColor(entityAirbus.getBodyColor());
        g.fillOval(_startPosX - 7, _startPosY + 45, 30, 8);
//Нос
        g.setColor(Color.BLACK);
        g.drawPolygon(new int[] {_startPosX + 175,_startPosX + 200, _startPosX + 175}, new int[] {_startPosY + 50, _startPosY + 65, _startPosY + 65}, 3);
        g.drawPolygon(new int[] {_startPosX + 175,_startPosX + 200, _startPosX + 175}, new int[] {_startPosY + 80, _startPosY + 65, _startPosY + 65}, 3);
        g.setColor(entityAirbus.getBodyColor());
        g.fillPolygon(new int[] {_startPosX + 175,_startPosX + 200, _startPosX + 175}, new int[] {_startPosY + 50, _startPosY + 65, _startPosY + 65}, 3);
        g.fillPolygon(new int[] {_startPosX + 175,_startPosX + 200, _startPosX + 175}, new int[] {_startPosY + 80, _startPosY + 65, _startPosY + 65}, 3);
//Крылья
        g.setColor(Color.BLACK);
        g.drawArc(_startPosX + 49, _startPosY + 62, 5, 5, 90, 180);
        g.drawLine( _startPosX + 51, _startPosY + 62, _startPosX + 140, _startPosY + 62);
        g.drawArc( _startPosX + 137, _startPosY + 62, 5, 5, 2790, 180);
        g.drawLine( _startPosX + 51, _startPosY + 67, _startPosX + 140, _startPosY + 67);
//Задние шасси
        g.drawLine(_startPosX + 55, _startPosY + 80, _startPosX + 55, _startPosY + 90);
        g.drawOval(_startPosX + 47, _startPosY + 90, 5, 5);
        g.drawOval( _startPosX + 57, _startPosY + 90, 5, 5);
        g.setColor(entityAirbus.getBodyColor());
        g.fillOval(_startPosX + 47, _startPosY + 90, 5, 5);
        g.fillOval( _startPosX + 57, _startPosY + 90, 5, 5);
//Передние шасси
        g.setColor(Color.BLACK);
        g.drawLine( _startPosX + 165, _startPosY + 80, _startPosX + 165, _startPosY + 90);
        g.drawOval( _startPosX + 163, _startPosY + 91, 5, 5);
        g.setColor(entityAirbus.getBodyColor());
        g.fillOval( _startPosX + 163, _startPosY + 91, 5, 5);
    }
}
